addpath('Erreur_flot/');

Ia = imread('data/deformation/1_0.jpg');
Ic = imread('data/deformation/1_3.jpg');

Ia=imresize(imfilter(Ia,fspecial('gaussian',7,1.),'same','replicate'),[256, NaN],'bicubic');
Ic=imresize(imfilter(Ic,fspecial('gaussian',7,1.),'same','replicate'),[256, NaN],'bicubic');

Ia=im2double(Ia);
Ic=im2double(Ic);

figure;
imshow([Ia, Ic]);

% We add a frame to the two images (the same) in order to "glue" it
% as well as the inside
MARGIN = 20;
fr = generate_frame(size(Ia));
Ia = add_frame(Ia, fr);
Ic = add_frame(Ic, fr);


% Step 2. Compute the dense SIFT image

% patchsize is half of the window size for computing SIFT
% gridspacing is the sampling precision
patchsize = 8;
gamma = 0.001;
alpha = 2;
d_para = 40;

gridspacing=1;

Sift1=dense_sift(Ia,patchsize,gridspacing);
Sift2=dense_sift(Ic,patchsize,gridspacing);

% Step 3. SIFT flow matching

% prepare the parameters
SIFTflowpara.alpha=alpha;
SIFTflowpara.d=d_para*alpha;
SIFTflowpara.gamma=gamma;
SIFTflowpara.nlevels=4;
SIFTflowpara.wsize=5;
SIFTflowpara.topwsize=20;
SIFTflowpara.nIterations=60;

tic;[vx,vy,energylist]=SIFTflowc2f(Sift1,Sift2,SIFTflowpara);
my_time = toc;

sigma = 30;

% Jv  =  ( dvx/dx   dvy/dx   dvx/dy   dvy/dy )

Jv = zeros(size(vx,1), size(vx,2), 4);

Jv(:,:,1) = derive_flot( sigma, vx, [1,0] );
Jv(:,:,3) = derive_flot( sigma, vx, [0,1] );
Jv(:,:,2) = derive_flot( sigma, vy, [1,0] );
Jv(:,:,4) = derive_flot( sigma, vy, [0,1] );


affiche_flot( Ia, Ic, vx, vy, 5, 0.5, 5);

thres = .2;
thresm = 0.1;
thresn = 0.1;

Ixy = zeros(size(Jv,1), size(Jv,2), 3);
Ixy(:,:,1) = (sum(Jv,3)>thres);
Ixy(:,:,3) = (sum(Jv,3)<-thres);
figure(4);imshow(Ixy);

JJ = sum(Jv,3);

Jmax = max(JJ(:));
Jmin = min(JJ(:));

JJ = max( min(JJ,Jmax - thresm), Jmin + thresn );

imagesc(JJ);


