function [vx,vy, gridx, gridy, energylist] = flowwithCNN( im1, im2, layer )

    if nargin < 3
        layer = 9;
    end

    im1=im2double(im1);
    im2=im2double(im2);

    [CNN1, gridx, gridy, im1m] = dense_cnn2( im1, layer );
    [CNN2, ~, ~, im2m] = dense_cnn2( im2, layer );


    % SIFT flow matching

    % prepare the parameters
    SIFTflowpara.alpha=2;
    SIFTflowpara.d=40;
    SIFTflowpara.gamma=0.005;
    SIFTflowpara.nlevels=4;
    SIFTflowpara.wsize=5;
    SIFTflowpara.topwsize=20;
    SIFTflowpara.nIterations=60;

    [vx,vy,energylist] = SIFTflowc2f( CNN1, CNN2, SIFTflowpara );

    [dy,dx] = size(vx);

    for i = 1:dy
        for j = 1:dx
            vx(i,j) = gridx( max(min( j+vx(i,j), dx ),1) ) - gridx(j);
            vy(i,j) = gridy( max(min( i+vy(i,j), dy ),1) ) - gridy(i);
        end
    end

    coefx = size(im1,2) / size(im1m,2);
    coefy = size(im1,1) / size(im1m,1);
    vx = vx * coefx;
    vy = vy * coefy;
    gridx = floor(gridx * coefx);
    gridy = floor(gridy * coefy);

end

