function [ error ] = test_flow( calcul_flow, I, nb )

    if nargin<3
        nb = 10;
    end
    
    if nargin<2
        % Chargement de l'image de base
        I = imread('Mars-1.jpg');
        % On change la taille de l'image qui est trop grande
        I = imresize( imfilter( I, fspecial('gaussian',7,1.), ...
                            'same','replicate'), ...
                  0.5, 'bicubic' );        
    end

    I = im2double(I);
    % On affiche l'image
    [dy, dx, ~] = size(I);
    [gx,gy] = meshgrid(1:dx,1:dy);
    
    error = zeros(nb+1,2);
    
% Premier test : deformation principale
    for i = 0:nb
        tic
        a = 15*(i/nb);
        f = i * (2 * pi) / (70*nb);
        vague = @(x,y) a * sin(f*y); % Fonction de deformation

        vxt = vague( gx, gy );
        vyt = zeros(size(gy));

        [I2, mask] = warpImage( I, vxt, vyt );
        
        [ vx, vy, gridx, gridy, ~ ] = calcul_flow( I2, I );
        vxt = vxt( gridy, gridx );
        vyt = vyt( gridy, gridx );
        mask = mask( gridy, gridx );

        nb_el = sum(sum(mask));
        error(i+1,1) = f;
        error(i+1,2) = sum(sum((sqrt((vxt-vx).^2 + (vyt-vy).^2)).*mask))/nb_el;
        
        error_mean = mean2(sqrt((vxt-vx).^2 + (vyt-vy).^2));
        figure(1);imshow(I);
        figure(2);imshow(I2);
        figure(3);imshow( warpImage( I(gridy,gridx,:), vx, vy ) );
        fprintf('%2.4f => error = %2.4f (<%2.4f)  [[nb = %i]]\n', f, error(i+1,2), error_mean, sum(sum(mask)));
        toc
        pause;
    end
    %
        
end

